==> jc-1.4.0.tar.gz: soot/AbstractUnitBox.h <==
// public abstract class soot.AbstractUnitBox

// class file dependencies
// @dep_class 2a7152deee1944f1 java_lang_Object
// @dep_class 5cec03cf39985907 soot_AbstractUnitBox

// header file dependencies
// @dep_header java_lang_Object

#include "java/lang/Object.h"

#ifndef _JC_soot_AbstractUnitBox_H_
#define _JC_soot_AbstractUnitBox_H_

// Forward structure declarations
struct _jc_java_lang_Class$object;
struct _jc_soot_Unit$object;
struct _jc_soot_UnitPrinter$object;

// Typedefs
typedef struct _jc_soot_AbstractUnitBox$sub_refs	_jc_soot_AbstractUnitBox$sub_refs;
typedef struct _jc_soot_AbstractUnitBox$sub_nonrefs	_jc_soot_AbstractUnitBox$sub_nonrefs;
typedef struct _jc_soot_AbstractUnitBox$refs	_jc_soot_AbstractUnitBox$refs;
typedef struct _jc_soot_AbstractUnitBox$nonrefs	_jc_soot_AbstractUnitBox$nonrefs;
typedef struct _jc_soot_AbstractUnitBox$object	_jc_soot_AbstractUnitBox$object;

typedef const struct _jc_soot_AbstractUnitBox$vmethods	_jc_soot_AbstractUnitBox$vmethods;
typedef const struct _jc_soot_AbstractUnitBox$vtable	_jc_soot_AbstractUnitBox$vtable;
typedef const struct _jc_soot_AbstractUnitBox$vtype	_jc_soot_AbstractUnitBox$vtype;

// Constructors
extern void _jc_soot_AbstractUnitBox$method$_init$52f4ad9f2989aeee(_jc_env *, struct _jc_soot_AbstractUnitBox$object *);

// Virtual methods
extern jboolean _jc_soot_AbstractUnitBox$method$canContainUnit$081e9f3eeb61f46c(_jc_env *, struct _jc_soot_AbstractUnitBox$object *, struct _jc_object *);
extern struct _jc_object *_jc_soot_AbstractUnitBox$method$getUnit$1c9f4c3a79dbf3ad(_jc_env *, struct _jc_soot_AbstractUnitBox$object *);
extern jboolean _jc_soot_AbstractUnitBox$method$isBranchTarget$12e95e9d8aecf52a(_jc_env *, struct _jc_soot_AbstractUnitBox$object *);
extern void _jc_soot_AbstractUnitBox$method$setUnit$1f000555fde5d34c(_jc_env *, struct _jc_soot_AbstractUnitBox$object *, struct _jc_object *);
extern void _jc_soot_AbstractUnitBox$method$toString$49ce0d4a4e59c2a6(_jc_env *, struct _jc_soot_AbstractUnitBox$object *, struct _jc_object *);

// Virtual method descriptors
extern _jc_method _jc_soot_AbstractUnitBox$method_info$canContainUnit$081e9f3eeb61f46c;
extern _jc_method _jc_soot_AbstractUnitBox$method_info$getUnit$1c9f4c3a79dbf3ad;
extern _jc_method _jc_soot_AbstractUnitBox$method_info$isBranchTarget$12e95e9d8aecf52a;
extern _jc_method _jc_soot_AbstractUnitBox$method_info$setUnit$1f000555fde5d34c;
extern _jc_method _jc_soot_AbstractUnitBox$method_info$toString$49ce0d4a4e59c2a6;

// Virtual methods structure
struct _jc_soot_AbstractUnitBox$vmethods {
	jboolean	(*canContainUnit$081e9f3eeb61f46c)(_jc_env *, struct _jc_soot_AbstractUnitBox$object *, struct _jc_object *);
	struct _jc_object	*(*getUnit$1c9f4c3a79dbf3ad)(_jc_env *, struct _jc_soot_AbstractUnitBox$object *);
	jboolean	(*isBranchTarget$12e95e9d8aecf52a)(_jc_env *, struct _jc_soot_AbstractUnitBox$object *);
	void	(*setUnit$1f000555fde5d34c)(_jc_env *, struct _jc_soot_AbstractUnitBox$object *, struct _jc_object *);
	void	(*toString$49ce0d4a4e59c2a6)(_jc_env *, struct _jc_soot_AbstractUnitBox$object *, struct _jc_object *);
};

// Vtable
struct _jc_soot_AbstractUnitBox$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_soot_AbstractUnitBox$vmethods	soot_AbstractUnitBox;
};

// Vtype
struct _jc_soot_AbstractUnitBox$vtype {
	_jc_type			type;
	_jc_soot_AbstractUnitBox$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_soot_AbstractUnitBox$sub_refs {
	struct _jc_object	*unit;
};

// Reference instance fields (object)
struct _jc_soot_AbstractUnitBox$refs {
    _jc_soot_AbstractUnitBox$sub_refs	soot_AbstractUnitBox;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_soot_AbstractUnitBox$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_soot_AbstractUnitBox$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_soot_AbstractUnitBox$sub_nonrefs	soot_AbstractUnitBox;
};

// Object instance structure
struct _jc_soot_AbstractUnitBox$object {
	_jc_soot_AbstractUnitBox$refs	refs[0];
	_jc_word		lockword;
	_jc_soot_AbstractUnitBox$vtype	*vtype;
	_jc_soot_AbstractUnitBox$nonrefs	nonrefs;
};

// Type structure
extern _jc_soot_AbstractUnitBox$vtype _jc_soot_AbstractUnitBox$type;

// Array types class info structures
_JC_DECL_ARRAYS(soot_AbstractUnitBox, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_soot_AbstractUnitBox$class_object;

#endif	/* _JC_soot_AbstractUnitBox_H_ */

==> jc-1.4.6.tar.gz: soot/AbstractUnitBox.h <==
// public abstract class soot.AbstractUnitBox

// class file dependencies
// @dep_class 1c4f1fc002fc96e5 java_lang_Object
// @dep_class 5cec03cf39985907 soot_AbstractUnitBox

// header file dependencies
// @dep_header java_lang_Object

#include "java/lang/Object.h"

#ifndef _JC_soot_AbstractUnitBox_H_
#define _JC_soot_AbstractUnitBox_H_

// Forward structure declarations
struct _jc_java_lang_Class$object;
struct _jc_soot_Unit$object;
struct _jc_soot_UnitPrinter$object;

// Typedefs
typedef struct _jc_soot_AbstractUnitBox$sub_refs	_jc_soot_AbstractUnitBox$sub_refs;
typedef struct _jc_soot_AbstractUnitBox$sub_nonrefs	_jc_soot_AbstractUnitBox$sub_nonrefs;
typedef struct _jc_soot_AbstractUnitBox$refs	_jc_soot_AbstractUnitBox$refs;
typedef struct _jc_soot_AbstractUnitBox$nonrefs	_jc_soot_AbstractUnitBox$nonrefs;
typedef struct _jc_soot_AbstractUnitBox$object	_jc_soot_AbstractUnitBox$object;

typedef const struct _jc_soot_AbstractUnitBox$vmethods	_jc_soot_AbstractUnitBox$vmethods;
typedef const struct _jc_soot_AbstractUnitBox$vtable	_jc_soot_AbstractUnitBox$vtable;
typedef const struct _jc_soot_AbstractUnitBox$vtype	_jc_soot_AbstractUnitBox$vtype;

// Constructors
extern void _jc_soot_AbstractUnitBox$method$_init$52f4ad9f2989aeee(_jc_env *, struct _jc_soot_AbstractUnitBox$object *) _JC_JCNI_ATTR;

// Virtual methods
extern jboolean _jc_soot_AbstractUnitBox$method$canContainUnit$081e9f3eeb61f46c(_jc_env *, struct _jc_soot_AbstractUnitBox$object *, struct _jc_object *) _JC_JCNI_ATTR;
extern struct _jc_object *_jc_soot_AbstractUnitBox$method$getUnit$1c9f4c3a79dbf3ad(_jc_env *, struct _jc_soot_AbstractUnitBox$object *) _JC_JCNI_ATTR;
extern jboolean _jc_soot_AbstractUnitBox$method$isBranchTarget$12e95e9d8aecf52a(_jc_env *, struct _jc_soot_AbstractUnitBox$object *) _JC_JCNI_ATTR;
extern void _jc_soot_AbstractUnitBox$method$setUnit$1f000555fde5d34c(_jc_env *, struct _jc_soot_AbstractUnitBox$object *, struct _jc_object *) _JC_JCNI_ATTR;
extern void _jc_soot_AbstractUnitBox$method$toString$49ce0d4a4e59c2a6(_jc_env *, struct _jc_soot_AbstractUnitBox$object *, struct _jc_object *) _JC_JCNI_ATTR;

// Virtual method descriptors
extern _jc_method _jc_soot_AbstractUnitBox$method_info$canContainUnit$081e9f3eeb61f46c;
extern _jc_method _jc_soot_AbstractUnitBox$method_info$getUnit$1c9f4c3a79dbf3ad;
extern _jc_method _jc_soot_AbstractUnitBox$method_info$isBranchTarget$12e95e9d8aecf52a;
extern _jc_method _jc_soot_AbstractUnitBox$method_info$setUnit$1f000555fde5d34c;
extern _jc_method _jc_soot_AbstractUnitBox$method_info$toString$49ce0d4a4e59c2a6;

// Virtual methods structure
struct _jc_soot_AbstractUnitBox$vmethods {
	jboolean	(*canContainUnit$081e9f3eeb61f46c)(_jc_env *, struct _jc_soot_AbstractUnitBox$object *, struct _jc_object *) _JC_JCNI_ATTR;
	struct _jc_object	*(*getUnit$1c9f4c3a79dbf3ad)(_jc_env *, struct _jc_soot_AbstractUnitBox$object *) _JC_JCNI_ATTR;
	jboolean	(*isBranchTarget$12e95e9d8aecf52a)(_jc_env *, struct _jc_soot_AbstractUnitBox$object *) _JC_JCNI_ATTR;
	void	(*setUnit$1f000555fde5d34c)(_jc_env *, struct _jc_soot_AbstractUnitBox$object *, struct _jc_object *) _JC_JCNI_ATTR;
	void	(*toString$49ce0d4a4e59c2a6)(_jc_env *, struct _jc_soot_AbstractUnitBox$object *, struct _jc_object *) _JC_JCNI_ATTR;
};

// Vtable
struct _jc_soot_AbstractUnitBox$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_soot_AbstractUnitBox$vmethods	soot_AbstractUnitBox;
};

// Vtype
struct _jc_soot_AbstractUnitBox$vtype {
	_jc_type			type;
	_jc_soot_AbstractUnitBox$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_soot_AbstractUnitBox$sub_refs {
	struct _jc_object	*unit;
};

// Reference instance fields (object)
struct _jc_soot_AbstractUnitBox$refs {
    _jc_soot_AbstractUnitBox$sub_refs	soot_AbstractUnitBox;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_soot_AbstractUnitBox$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_soot_AbstractUnitBox$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_soot_AbstractUnitBox$sub_nonrefs	soot_AbstractUnitBox;
};

// Object instance structure
struct _jc_soot_AbstractUnitBox$object {
	_jc_soot_AbstractUnitBox$refs	refs[0];
	_jc_word		lockword;
	_jc_soot_AbstractUnitBox$vtype	*vtype;
	_jc_soot_AbstractUnitBox$nonrefs	nonrefs;
};

// Type structure
extern _jc_soot_AbstractUnitBox$vtype _jc_soot_AbstractUnitBox$type;

// Array types class info structures
_JC_DECL_ARRAYS(soot_AbstractUnitBox, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_soot_AbstractUnitBox$class_object;

#endif	/* _JC_soot_AbstractUnitBox_H_ */
